pub struct MockMessagePoll {Show 38 fields
pub id: MessageId,
pub thread_id: Option<ThreadId>,
pub from: Option<User>,
pub sender_chat: Option<Chat>,
pub date: DateTime<Utc>,
pub chat: Chat,
pub is_topic_message: bool,
pub via_bot: Option<User>,
pub sender_business_bot: Option<User>,
pub author_signature: Option<String>,
pub paid_star_count: Option<u32>,
pub effect_id: Option<EffectId>,
pub forward_origin: Option<MessageOrigin>,
pub reply_to_message: Option<Box<Message>>,
pub external_reply: Option<ExternalReplyInfo>,
pub quote: Option<TextQuote>,
pub edit_date: Option<DateTime<Utc>>,
pub reply_markup: Option<InlineKeyboardMarkup>,
pub is_automatic_forward: bool,
pub has_protected_content: bool,
pub is_from_offline: bool,
pub business_connection_id: Option<BusinessConnectionId>,
pub reply_to_story: Option<Story>,
pub sender_boost_count: Option<u16>,
pub poll_id: PollId,
pub question: String,
pub question_entities: Option<Vec<MessageEntity>>,
pub options: Vec<PollOption>,
pub is_closed: bool,
pub total_voter_count: u32,
pub is_anonymous: bool,
pub poll_type: PollType,
pub allows_multiple_answers: bool,
pub correct_option_id: Option<u8>,
pub explanation: Option<String>,
pub explanation_entities: Option<Vec<MessageEntity>>,
pub open_period: Option<Seconds>,
pub close_date: Option<DateTime<Utc>>,
}Fields
id: MessageIdthread_id: Option<ThreadId>from: Option<User>sender_chat: Option<Chat>date: DateTime<Utc>chat: Chatis_topic_message: boolvia_bot: Option<User>sender_business_bot: Option<User>paid_star_count: Option<u32>effect_id: Option<EffectId>forward_origin: Option<MessageOrigin>reply_to_message: Option<Box<Message>>external_reply: Option<ExternalReplyInfo>quote: Option<TextQuote>edit_date: Option<DateTime<Utc>>reply_markup: Option<InlineKeyboardMarkup>is_automatic_forward: boolhas_protected_content: boolis_from_offline: boolbusiness_connection_id: Option<BusinessConnectionId>reply_to_story: Option<Story>sender_boost_count: Option<u16>poll_id: PollIdquestion: Stringquestion_entities: Option<Vec<MessageEntity>>options: Vec<PollOption>is_closed: booltotal_voter_count: u32is_anonymous: boolpoll_type: PollTypeallows_multiple_answers: boolcorrect_option_id: Option<u8>explanation: Option<String>explanation_entities: Option<Vec<MessageEntity>>open_period: Option<Seconds>close_date: Option<DateTime<Utc>>Implementations
Sourceimpl MockMessagePoll
impl MockMessagePoll
Sourcepub fn id(self, value: i32) -> Self
pub fn id(self, value: i32) -> Self
Sets the id value of the MockMessagePoll to value, converting it to MessageId.
Example
use teloxide_tests::MockMessagePoll;
let builder = MockMessagePoll::new().id(1234);
assert_eq!(builder.id, teloxide::types::MessageId(1234));Sourcepub fn thread_id<T: Into<ThreadId>>(self, value: T) -> Self
pub fn thread_id<T: Into<ThreadId>>(self, value: T) -> Self
Sets the thread_id value of the MockMessagePoll to value, converting it to needed Option type.
Sourcepub fn from<T: Into<User>>(self, value: T) -> Self
pub fn from<T: Into<User>>(self, value: T) -> Self
Sets the from value of the MockMessagePoll to value, converting it to needed Option type.
Sourcepub fn sender_chat<T: Into<Chat>>(self, value: T) -> Self
pub fn sender_chat<T: Into<Chat>>(self, value: T) -> Self
Sets the sender_chat value of the MockMessagePoll to value, converting it to needed Option type.
Sourcepub fn date(self, value: DateTime<Utc>) -> Self
pub fn date(self, value: DateTime<Utc>) -> Self
Sets the date value of the MockMessagePoll to value.
Sourcepub fn is_topic_message(self, value: bool) -> Self
pub fn is_topic_message(self, value: bool) -> Self
Sets the is_topic_message value of the MockMessagePoll to value.
Sourcepub fn via_bot<T: Into<User>>(self, value: T) -> Self
pub fn via_bot<T: Into<User>>(self, value: T) -> Self
Sets the via_bot value of the MockMessagePoll to value, converting it to needed Option type.
Sourcepub fn sender_business_bot<T: Into<User>>(self, value: T) -> Self
pub fn sender_business_bot<T: Into<User>>(self, value: T) -> Self
Sets the sender_business_bot value of the MockMessagePoll to value, converting it to needed Option type.
Sets the author_signature value of the MockMessagePoll to value, converting it to needed Option type.
Sourcepub fn paid_star_count<T: Into<u32>>(self, value: T) -> Self
pub fn paid_star_count<T: Into<u32>>(self, value: T) -> Self
Sets the paid_star_count value of the MockMessagePoll to value, converting it to needed Option type.
Sourcepub fn effect_id<T: Into<EffectId>>(self, value: T) -> Self
pub fn effect_id<T: Into<EffectId>>(self, value: T) -> Self
Sets the effect_id value of the MockMessagePoll to value, converting it to needed Option type.
Sourcepub fn forward_origin<T: Into<MessageOrigin>>(self, value: T) -> Self
pub fn forward_origin<T: Into<MessageOrigin>>(self, value: T) -> Self
Sets the forward_origin value of the MockMessagePoll to value, converting it to needed Option type.
Sourcepub fn reply_to_message<T: Into<Box<Message>>>(self, value: T) -> Self
pub fn reply_to_message<T: Into<Box<Message>>>(self, value: T) -> Self
Sets the reply_to_message value of the MockMessagePoll to value, converting it to needed Option type.
Sourcepub fn external_reply<T: Into<ExternalReplyInfo>>(self, value: T) -> Self
pub fn external_reply<T: Into<ExternalReplyInfo>>(self, value: T) -> Self
Sets the external_reply value of the MockMessagePoll to value, converting it to needed Option type.
Sourcepub fn quote<T: Into<TextQuote>>(self, value: T) -> Self
pub fn quote<T: Into<TextQuote>>(self, value: T) -> Self
Sets the quote value of the MockMessagePoll to value, converting it to needed Option type.
Sourcepub fn edit_date<T: Into<DateTime<Utc>>>(self, value: T) -> Self
pub fn edit_date<T: Into<DateTime<Utc>>>(self, value: T) -> Self
Sets the edit_date value of the MockMessagePoll to value, converting it to needed Option type.
Sourcepub fn reply_markup<T: Into<InlineKeyboardMarkup>>(self, value: T) -> Self
pub fn reply_markup<T: Into<InlineKeyboardMarkup>>(self, value: T) -> Self
Sets the reply_markup value of the MockMessagePoll to value, converting it to needed Option type.
Sourcepub fn is_automatic_forward(self, value: bool) -> Self
pub fn is_automatic_forward(self, value: bool) -> Self
Sets the is_automatic_forward value of the MockMessagePoll to value.
Sourcepub fn has_protected_content(self, value: bool) -> Self
pub fn has_protected_content(self, value: bool) -> Self
Sets the has_protected_content value of the MockMessagePoll to value.
Sourcepub fn is_from_offline(self, value: bool) -> Self
pub fn is_from_offline(self, value: bool) -> Self
Sets the is_from_offline value of the MockMessagePoll to value.
Sourcepub fn business_connection_id<T: Into<BusinessConnectionId>>(
self,
value: T,
) -> Self
pub fn business_connection_id<T: Into<BusinessConnectionId>>( self, value: T, ) -> Self
Sets the business_connection_id value of the MockMessagePoll to value, converting it to needed Option type.
Sourcepub fn reply_to_story<T: Into<Story>>(self, value: T) -> Self
pub fn reply_to_story<T: Into<Story>>(self, value: T) -> Self
Sets the reply_to_story value of the MockMessagePoll to value, converting it to needed Option type.
Sourcepub fn sender_boost_count<T: Into<u16>>(self, value: T) -> Self
pub fn sender_boost_count<T: Into<u16>>(self, value: T) -> Self
Sets the sender_boost_count value of the MockMessagePoll to value, converting it to needed Option type.
Sourcepub fn poll_id(self, value: PollId) -> Self
pub fn poll_id(self, value: PollId) -> Self
Sets the poll_id value of the MockMessagePoll to value.
Sourcepub fn question<T: Into<String>>(self, value: T) -> Self
pub fn question<T: Into<String>>(self, value: T) -> Self
Sets the question value of the MockMessagePoll to value, converting it to String.
Example
use teloxide_tests::MockMessagePoll;
let builder = MockMessagePoll::new().question("test");
assert_eq!(builder.question, "test".to_string());Sourcepub fn question_entities<T: Into<Vec<MessageEntity>>>(self, value: T) -> Self
pub fn question_entities<T: Into<Vec<MessageEntity>>>(self, value: T) -> Self
Sets the question_entities value of the MockMessagePoll to value, converting it to needed Option type.
Sourcepub fn options(self, value: Vec<PollOption>) -> Self
pub fn options(self, value: Vec<PollOption>) -> Self
Sets the options value of the MockMessagePoll to value.
Sourcepub fn is_closed(self, value: bool) -> Self
pub fn is_closed(self, value: bool) -> Self
Sets the is_closed value of the MockMessagePoll to value.
Sourcepub fn total_voter_count(self, value: u32) -> Self
pub fn total_voter_count(self, value: u32) -> Self
Sets the total_voter_count value of the MockMessagePoll to value.
Sourcepub fn is_anonymous(self, value: bool) -> Self
pub fn is_anonymous(self, value: bool) -> Self
Sets the is_anonymous value of the MockMessagePoll to value.
Sourcepub fn poll_type(self, value: PollType) -> Self
pub fn poll_type(self, value: PollType) -> Self
Sets the poll_type value of the MockMessagePoll to value.
Sourcepub fn allows_multiple_answers(self, value: bool) -> Self
pub fn allows_multiple_answers(self, value: bool) -> Self
Sets the allows_multiple_answers value of the MockMessagePoll to value.
Sourcepub fn correct_option_id<T: Into<u8>>(self, value: T) -> Self
pub fn correct_option_id<T: Into<u8>>(self, value: T) -> Self
Sets the correct_option_id value of the MockMessagePoll to value, converting it to needed Option type.
Sourcepub fn explanation<T: Into<String>>(self, value: T) -> Self
pub fn explanation<T: Into<String>>(self, value: T) -> Self
Sets the explanation value of the MockMessagePoll to value, converting it to needed Option type.
Sourcepub fn explanation_entities<T: Into<Vec<MessageEntity>>>(self, value: T) -> Self
pub fn explanation_entities<T: Into<Vec<MessageEntity>>>(self, value: T) -> Self
Sets the explanation_entities value of the MockMessagePoll to value, converting it to needed Option type.
Sourcepub fn open_period<T: Into<Seconds>>(self, value: T) -> Self
pub fn open_period<T: Into<Seconds>>(self, value: T) -> Self
Sets the open_period value of the MockMessagePoll to value, converting it to needed Option type.
Sourcepub fn close_date<T: Into<DateTime<Utc>>>(self, value: T) -> Self
pub fn close_date<T: Into<DateTime<Utc>>>(self, value: T) -> Self
Sets the close_date value of the MockMessagePoll to value, converting it to needed Option type.
Sourceimpl MockMessagePoll
impl MockMessagePoll
pub const IS_AUTOMATIC_FORWARD: bool = false
pub const HAS_PROTECTED_CONTENT: bool = false
pub const IS_FROM_OFFLINE: bool = false
Sourceimpl MockMessagePoll
impl MockMessagePoll
pub const POLL_ID: &'static str = "12345"
pub const QUESTION: &'static str = "Question"
pub const IS_CLOSED: bool = true
pub const IS_ANONYMOUS: bool = true
pub const TOTAL_VOTER_COUNT: u32 = 50
pub const POLL_TYPE: PollType = PollType::Regular
pub const ALLOW_MULTIPLE_ANSWERS: bool = true